# coding: utf-8

"""
    PAY.JP API v2

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0.0
    Contact: support@pay.jp
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class PaymentDisputeStatus(str, Enum):
    """
    PaymentDisputeStatus
    """

    """
    allowed enum values
    """
    PRE_WARNING_NEEDS_RESPONSE = 'pre_warning_needs_response'
    WARNING_NEEDS_RESPONSE = 'warning_needs_response'
    WARNING_NEEDS_REFUND = 'warning_needs_refund'
    WARNING_UNDER_REVIEW = 'warning_under_review'
    NEEDS_RESPONSE = 'needs_response'
    UNDER_REVIEW = 'under_review'
    LOST = 'lost'
    CANCEL = 'cancel'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of PaymentDisputeStatus from a JSON string"""
        return cls(json.loads(json_str))


