# coding: utf-8

"""
    PAY.JP API v2

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0.0
    Contact: support@pay.jp
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from payjpv2.models.setup_flow_list_response import SetupFlowListResponse

class TestSetupFlowListResponse(unittest.TestCase):
    """SetupFlowListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SetupFlowListResponse:
        """Test SetupFlowListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SetupFlowListResponse`
        """
        model = SetupFlowListResponse()
        if include_optional:
            return SetupFlowListResponse(
                object = 'list',
                url = '',
                has_more = True,
                data = [
                    payjpv2.models.setup_flow_response.SetupFlowResponse(
                        object = 'setup_flow', 
                        id = '', 
                        livemode = True, 
                        client_secret = '', 
                        customer_id = '', 
                        description = '', 
                        metadata = {
                            'key' : null
                            }, 
                        payment_method_id = '', 
                        payment_method_options = { }, 
                        payment_method_types = [
                            'card'
                            ], 
                        status = 'canceled', 
                        next_action = { }, 
                        return_url = '', 
                        last_setup_error = { }, 
                        cancellation_reason = 'abandoned', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ]
            )
        else:
            return SetupFlowListResponse(
                url = '',
                has_more = True,
                data = [
                    payjpv2.models.setup_flow_response.SetupFlowResponse(
                        object = 'setup_flow', 
                        id = '', 
                        livemode = True, 
                        client_secret = '', 
                        customer_id = '', 
                        description = '', 
                        metadata = {
                            'key' : null
                            }, 
                        payment_method_id = '', 
                        payment_method_options = { }, 
                        payment_method_types = [
                            'card'
                            ], 
                        status = 'canceled', 
                        next_action = { }, 
                        return_url = '', 
                        last_setup_error = { }, 
                        cancellation_reason = 'abandoned', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
        )
        """

    def testSetupFlowListResponse(self):
        """Test SetupFlowListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
