# coding: utf-8

"""
    PAY.JP API v2

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0.0
    Contact: support@pay.jp
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from payjpv2.api.setup_flows_api import SetupFlowsApi


class TestSetupFlowsApi(unittest.TestCase):
    """SetupFlowsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SetupFlowsApi()

    def tearDown(self) -> None:
        pass

    def test_cancel_setup_flow(self) -> None:
        """Test case for cancel_setup_flow

        Cancel Setup Flow
        """
        pass

    def test_create_setup_flow(self) -> None:
        """Test case for create_setup_flow

        Create Setup Flow
        """
        pass

    def test_get_all_setup_flows(self) -> None:
        """Test case for get_all_setup_flows

        Get All Setup Flows
        """
        pass

    def test_get_setup_flow(self) -> None:
        """Test case for get_setup_flow

        Get Setup Flow
        """
        pass

    def test_update_setup_flow(self) -> None:
        """Test case for update_setup_flow

        Update Setup Flow
        """
        pass


if __name__ == '__main__':
    unittest.main()
