# coding: utf-8

"""
    PAY.JP API v2

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0.0
    Contact: support@pay.jp
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from payjpv2.models.payment_method_configuration_setting_response import PaymentMethodConfigurationSettingResponse
from typing import Optional, Set
from typing_extensions import Self

class PaymentMethodConfigurationDetailsResponse(BaseModel):
    """
    PaymentMethodConfigurationDetailsResponse
    """ # noqa: E501
    object: Optional[StrictStr] = 'payment_method_configuration'
    id: StrictStr = Field(description="支払い方法設定 ID")
    livemode: StrictBool = Field(description="本番環境かどうか")
    active: StrictBool = Field(description="設定が有効かどうか")
    name: Optional[StrictStr]
    paypay: PaymentMethodConfigurationSettingResponse = Field(description="PayPay の設定")
    card: PaymentMethodConfigurationSettingResponse = Field(description="カードの設定")
    apple_pay: PaymentMethodConfigurationSettingResponse = Field(description="Apple Pay の設定")
    __properties: ClassVar[List[str]] = ["object", "id", "livemode", "active", "name", "paypay", "card", "apple_pay"]

    @field_validator('object')
    def object_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['payment_method_configuration']):
            raise ValueError("must be one of enum values ('payment_method_configuration')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.model_dump(by_alias=True, exclude_unset=True))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PaymentMethodConfigurationDetailsResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of paypay
        if self.paypay:
            _dict['paypay'] = self.paypay.to_dict()
        # override the default output from pydantic by calling `to_dict()` of card
        if self.card:
            _dict['card'] = self.card.to_dict()
        # override the default output from pydantic by calling `to_dict()` of apple_pay
        if self.apple_pay:
            _dict['apple_pay'] = self.apple_pay.to_dict()
        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict['name'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PaymentMethodConfigurationDetailsResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "object": obj.get("object") if obj.get("object") is not None else 'payment_method_configuration',
            "id": obj.get("id"),
            "livemode": obj.get("livemode"),
            "active": obj.get("active"),
            "name": obj.get("name"),
            "paypay": PaymentMethodConfigurationSettingResponse.from_dict(obj["paypay"]) if obj.get("paypay") is not None else None,
            "card": PaymentMethodConfigurationSettingResponse.from_dict(obj["card"]) if obj.get("card") is not None else None,
            "apple_pay": PaymentMethodConfigurationSettingResponse.from_dict(obj["apple_pay"]) if obj.get("apple_pay") is not None else None
        })
        return _obj


