# coding: utf-8

"""
    PAY.JP API v2

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0.0
    Contact: support@pay.jp
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from payjpv2.models.payment_method_configuration_list_response import PaymentMethodConfigurationListResponse

class TestPaymentMethodConfigurationListResponse(unittest.TestCase):
    """PaymentMethodConfigurationListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaymentMethodConfigurationListResponse:
        """Test PaymentMethodConfigurationListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaymentMethodConfigurationListResponse`
        """
        model = PaymentMethodConfigurationListResponse()
        if include_optional:
            return PaymentMethodConfigurationListResponse(
                object = 'list',
                url = '',
                has_more = True,
                data = [
                    payjpv2.models.payment_method_configuration_details_response.PaymentMethodConfigurationDetailsResponse(
                        object = 'payment_method_configuration', 
                        id = '', 
                        livemode = True, 
                        active = True, 
                        name = '', 
                        paypay = payjpv2.models.payment_method_configuration_setting_response.PaymentMethodConfigurationSettingResponse(
                            available = True, 
                            display_preference = payjpv2.models.payment_method_configuration_display_preference.PaymentMethodConfigurationDisplayPreference(
                                preference = 'none', 
                                value = 'off', ), ), 
                        card = payjpv2.models.payment_method_configuration_setting_response.PaymentMethodConfigurationSettingResponse(
                            available = True, ), 
                        apple_pay = , )
                    ]
            )
        else:
            return PaymentMethodConfigurationListResponse(
                url = '',
                has_more = True,
                data = [
                    payjpv2.models.payment_method_configuration_details_response.PaymentMethodConfigurationDetailsResponse(
                        object = 'payment_method_configuration', 
                        id = '', 
                        livemode = True, 
                        active = True, 
                        name = '', 
                        paypay = payjpv2.models.payment_method_configuration_setting_response.PaymentMethodConfigurationSettingResponse(
                            available = True, 
                            display_preference = payjpv2.models.payment_method_configuration_display_preference.PaymentMethodConfigurationDisplayPreference(
                                preference = 'none', 
                                value = 'off', ), ), 
                        card = payjpv2.models.payment_method_configuration_setting_response.PaymentMethodConfigurationSettingResponse(
                            available = True, ), 
                        apple_pay = , )
                    ],
        )
        """

    def testPaymentMethodConfigurationListResponse(self):
        """Test PaymentMethodConfigurationListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
