# coding: utf-8

"""
    PAY.JP API v2

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0.0
    Contact: support@pay.jp
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from payjpv2.models.payment_method_card_update_request import PaymentMethodCardUpdateRequest

class TestPaymentMethodCardUpdateRequest(unittest.TestCase):
    """PaymentMethodCardUpdateRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaymentMethodCardUpdateRequest:
        """Test PaymentMethodCardUpdateRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaymentMethodCardUpdateRequest`
        """
        model = PaymentMethodCardUpdateRequest()
        if include_optional:
            return PaymentMethodCardUpdateRequest(
                billing_details = payjpv2.models.payment_method_billing_details_request.PaymentMethodBillingDetailsRequest(
                    name = '', 
                    phone = '', 
                    email = '', 
                    address = payjpv2.models.payment_method_billing_address_request.PaymentMethodBillingAddressRequest(
                        country = '', 
                        zip = '', 
                        state = '', 
                        city = '', 
                        line1 = '', 
                        line2 = '', ), ),
                metadata = {
                    'key' : null
                    },
                type = 'card'
            )
        else:
            return PaymentMethodCardUpdateRequest(
                type = 'card',
        )
        """

    def testPaymentMethodCardUpdateRequest(self):
        """Test PaymentMethodCardUpdateRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
