# coding: utf-8

"""
    PAY.JP API v2

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0.0
    Contact: support@pay.jp
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class PaymentDisputeReason(str, Enum):
    """
    PaymentDisputeReason
    """

    """
    allowed enum values
    """
    RESEARCHING = 'researching'
    RESEARCHING_FRAUDULENT = 'researching_fraudulent'
    WARNED_FRAUDULENT = 'warned_fraudulent'
    CONFIRMED_FRAUDULENT = 'confirmed_fraudulent'
    UNRECOGNIZED = 'unrecognized'
    FRAUDULENT = 'fraudulent'
    PRODUCT_NOT_RECEIVED = 'product_not_received'
    ONLINE_FRAUDULENT = 'online_fraudulent'
    INCORRECT_ACCOUNT_DETAILS = 'incorrect_account_details'
    RECEIVING_CHARGEBACK = 'receiving_chargeback'
    DUPLICATE = 'duplicate'
    NOT_AUTHORIZED = 'not_authorized'
    SUBSCRIPTION_CANCELED = 'subscription_canceled'
    CHECK_RETURNED = 'check_returned'
    OTHER = 'other'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of PaymentDisputeReason from a JSON string"""
        return cls(json.loads(json_str))


