# coding: utf-8

"""
    PAY.JP API v2

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0.0
    Contact: support@pay.jp
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from payjpv2.api.payment_refunds_api import PaymentRefundsApi


class TestPaymentRefundsApi(unittest.TestCase):
    """PaymentRefundsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PaymentRefundsApi()

    def tearDown(self) -> None:
        pass

    def test_create_payment_refund(self) -> None:
        """Test case for create_payment_refund

        Create Payment Refund
        """
        pass

    def test_get_all_payment_refunds(self) -> None:
        """Test case for get_all_payment_refunds

        Get All Payment Refunds
        """
        pass

    def test_get_payment_refund(self) -> None:
        """Test case for get_payment_refund

        Get Payment Refund
        """
        pass

    def test_update_payment_refund(self) -> None:
        """Test case for update_payment_refund

        Update Payment Refund
        """
        pass


if __name__ == '__main__':
    unittest.main()
