# coding: utf-8

"""
    PAY.JP API v2

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0.0
    Contact: support@pay.jp
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from payjpv2.api.payment_disputes_api import PaymentDisputesApi


class TestPaymentDisputesApi(unittest.TestCase):
    """PaymentDisputesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PaymentDisputesApi()

    def tearDown(self) -> None:
        pass

    def test_get_all_payment_disputes(self) -> None:
        """Test case for get_all_payment_disputes

        Get All Payment Disputes
        """
        pass

    def test_get_payment_dispute(self) -> None:
        """Test case for get_payment_dispute

        Get Payment Dispute
        """
        pass


if __name__ == '__main__':
    unittest.main()
